======================================
``psyclone.psyir.nodes.nan_test_node``
======================================

.. automodule:: psyclone.psyir.nodes.nan_test_node

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.nan_test_node


Classes
=======

- :py:class:`NanTestNode`:
  This class can be inserted into a Schedule to mark Nodes for


.. autoclass:: NanTestNode
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: NanTestNode
      :parts: 1
